# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	Framework for parsing POD documentation
Name:		perl-Pod-Simple
Epoch:		1
Version:	3.47
Release:	1.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Pod-Simple
Source0:	https://cpan.metacpan.org/modules/by-module/Pod/Pod-Simple-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.76
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Config)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Getopt::Long)
BuildRequires:	perl(HTML::Entities)
BuildRequires:	perl(if)
BuildRequires:	perl(integer)
BuildRequires:	perl(overload)
BuildRequires:	perl(Pod::Escapes) >= 1.04
BuildRequires:	perl(strict)
BuildRequires:	perl(Symbol)
BuildRequires:	perl(Text::Wrap) >= 98.112902
BuildRequires:	perl(utf8)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(base)
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(Encode)
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Path)
BuildRequires:	perl(FindBin)
BuildRequires:	perl(parent)
BuildRequires:	perl(Test::More) >= 0.88
BuildRequires:	perl(vars)
# Optional Tests
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(Test::Deep)
BuildRequires:	perl(Text::Diff)
# Runtime
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(HTML::Entities)

%description
Pod::Simple is a Perl library for parsing text in the Pod ("plain old
documentation") markup language that is typically used for writing
documentation for Perl and for Perl modules. The Pod format is explained in the
perlpod man page; the most common formatter is called "perldoc".

Pod formatters can use Pod::Simple to parse Pod documents to produce renderings
of them in plain ASCII, in HTML, or in any number of other formats. Typically,
such formatters will be subclasses of Pod::Simple, and so they will inherit its
methods, like parse_file

%prep
%setup -q -n Pod-Simple-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor NO_PACKLIST=1 NO_PERLLOCAL=1
%{make_build}

%install
%{make_install}
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc README ChangeLog
%dir %{perl_vendorlib}/Pod/
%dir %{perl_vendorlib}/Pod/Simple/
%{perl_vendorlib}/Pod/Simple.pm
%{perl_vendorlib}/Pod/Simple/*.pm
%doc %{perl_vendorlib}/Pod/Simple.pod
%doc %{perl_vendorlib}/Pod/Simple/Subclassing.pod
%{_mandir}/man3/Pod::Simple.3*
%{_mandir}/man3/Pod::Simple::*

%changelog
* Fri May 16 2025 Paul Howarth <paul@city-fan.org> - 1:3.47-1
- Update to 3.47
  - No git-related files in MANIFEST (GH#183)
  - Rename method and field to avoid conflicts (GH#185)

* Mon May 12 2025 Paul Howarth <paul@city-fan.org> - 1:3.46-1
- Update to 3.46
  - XHTML: =over without =item should render as a blockquote
  - Add support for underlined text U<> formatting
  - Make 'temp' name checking more succinct
  - GitHub: Fix and add tests
  - Makefile.PL: Add missing 'warnings' prereq
  - Add select method compatible with Pod::Select
  - Modernize htmlbat.t, corpus.t
  - Fix links, typos, acknowledgments
  - Add documentation on subclassing
  - Fix version checking
  - Fix version number
  - Use rel2abs instead of abs_path
- Use %%{make_build} and %%{make_install}

* Tue May 16 2023 Paul Howarth <paul@city-fan.org> - 1:3.45-1
- Update to 3.45
  - Use Test::More and clean up tests
  - Reorganize Makefile.PL warnings
  - use warnings
  - Clean up of whitespace and for prehistoric perls
  - Fix precedence issue in PullParser
  - Minor parallelism fixes to test files
  - Refactor XHTML index generation into own method
  - Fix tab expansion when not 0 nor 8
  - Various fixes to links
- Use SPDX-format license tag

* Tue Jun 29 2021 Paul Howarth <paul@city-fan.org> - 1:3.43-1
- Update to 3.43
  - Remove pod markup from README
  - Update homepage to metacpan
  - "use" not "require" Pod::Simple::TiedOutFH (GH#131)

* Sun Nov 15 2020 Paul Howarth <paul@city-fan.org> - 1:3.42-1
- Update to 3.42
  - Drop EUMM version prereq (GH#130)

* Tue Oct 13 2020 Paul Howarth <paul@city-fan.org> - 1:3.41-1
- Update to 3.41
  - Factorize tests functions in one helper module
  - Support =head5, =head6
  - Support SOURCE_DATE_EPOCH
  - Enforce warnings for tests
  - Add GitHub CI
  - Suppress "UTF-16 surrogate 0xd800" warning
- Add patch to support building with ExtUtils::MakeMaker < 6.64

* Sun Oct 27 2019 Paul Howarth <paul@city-fan.org> - 1:3.40-1
- Update to 3.40
  - Make case sensitivity determination overridable by user (GH#111)
  - Add expand_verbatim_tabs() method, which also can turn off expansion,
    fixing GH#110

* Mon Jul  1 2019 Paul Howarth <paul@city-fan.org> - 1:3.39-1
- Update to 3.39
  - Fixed JustPod not opening file with :raw
  - Fixed garbage line looking like pod
  - Finished fixing GH#95 by adding note that = in column 1 can be
    misinterpreted as pod

* Fri May 31 2019 Paul Howarth <paul@city-fan.org> - 1:3.38-1
- Update to 3.38
  - Removed some alien files that somehow got in the tar, including a copy of
    Pod::Escapes

* Wed May 22 2019 Paul Howarth <paul@city-fan.org> - 1:3.36-1
- Update to 3.36
  - Added Pod::Simple::JustPod to extract the pod lines from a file
  - Improved detection of input encoding CP1252 vs. UTF-8
  - Fixed =cut event out of order (GH#79)
  - Fixed verbatim_indent doesn't work on HTML (GH#85)
  - Fixed css files refer to themselves (GH#89)
  - Fixed broken RTF with Unicode inputs (GH#92)
  - Extended RTF to handle Unicode code points above 0xFFFF
  - Nested L<> is now flagged as an error
  - Turned off negative repeat count does nothing warnings
  - Fixed/improved some docs about this distribution
- Switch upstream from search.cpan.org to metacpan.org

* Mon Apr 16 2018 Paul Howarth <paul@city-fan.org> - 1:3.35-395
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Sun Dec  4 2016 Paul Howarth <paul@city-fan.org> - 1:3.35-1
- Update to 3.35
  - Stabilize t/search50.t
  - Turn off utf8 warnings when trying to see if a file is UTF-8 or not
- This release by KHW → update source URL

* Thu Sep 22 2016 Paul Howarth <paul@city-fan.org> - 1:3.32-365
- BR: perl-generators where available
- Simplify find command using -delete

* Tue Nov  3 2015 Paul Howarth <paul@city-fan.org> - 1:3.32-1
- Update to 3.32
  - Fixed failing tests on Windows
  - Switched debugging output from STDOUT to STDERR; should rarely be used,
    but modules that do depend on debugging output might need to change how
    they handle it (GitHub Pull Request #76)
  - Added errata_seen() to make POD errors easily accessible

* Wed Sep  2 2015 Paul Howarth <paul@city-fan.org> - 1:3.31-1
- Update to 3.31
  - Simplified the detection of case-insensitivity in Pod::Simple::Search
  - Fixed "Use of uninitialized value $1 in lc" warning in Pod::Simple::Search
  - If @INC includes the current directory symbol, '.', the survey() method of
    Pod::Simple::Search no longer excludes it from its list of directories to
    search; instead, The survey() and find() methods now both exclude duplicate
    directories from @INC (CPAN RT#102344)
  - Moved source repository and updated links to new perl-pod GitHub
    organization: https://github.com/perl-pod/pod-simple
  - Improved repository links and added GitHub issue tracking link to the
    distribution metadata
  - Switched from File::Spec's catdir to catfile for path names, to fix
    failures on VMS; also now use Unix path semantics where they're not
    required to be platform-specific (CPAN RT#105511)
  - Improved the example use of the 'html_encode_chars()' method in the
    Pod::Simple::XHTML documentation
- This release by MARCGREEN → update source URL

* Tue Jun 16 2015 Paul Howarth <paul@city-fan.org> - 1:3.30-2
- Perl 5.22 rebuild

* Tue Feb 24 2015 Paul Howarth <paul@city-fan.org> - 1:3.30-1
- Update to 3.30
  - Tightened up the first pass at recognizing a Pod command so that fewer
    invalid Pod lines will be recognized
  - Fixed bug where Pod::Simple would attempt to call utf8::unicode_to_native
    on Perl 5.6, where that function does not exist
  - Typos and minor wordsmithing changes in Pod::Simple::Subclassing
  - The Pod::Simple::Search survey() and find() methods now use the same code
    for determining @INC directories to search; the only difference is that
    find() also includes $Config::Config{'scriptdir'}
  - Removed "Caveats" from the docs: Pod::Simple has been out of beta for years
  - The survey() method in Pod::Simple::Search no longer assumes that files
    ending in '.pod' are actually Pod; like .pm and .pl files, .pod files must
    contain at least one valid POD command, as documented, which brings the
    behaviour in line with find(), which already required that .pod files
    contain Pod
  - The survey() method in Pod::Simple::Search now ignores duplicate files with
    varying lettercasing on case-insensitive file systems
  - When pondering files in a given directory, the survey() method in
    Pod::Simple::Search now prefers files with extensions in the following
    order: no extension, .pod, .pm, .plx, .pl
  - The find() method in Pod::Simple::Search now records the './pod'
    subdirectory of each directory it considers in such a way as to preserve
    its case on the file system
  - The find() method in Pod::Simple::Search now tries harder to find the
    proper file on case-insensitive file systems when searching for modules
    starting with "Pod", e.g. when searching for 'Pod::Perldoc', it now returns
    a file ending in 'Pod/Perldoc.pm' instead of 'Pod/perldoc.pod', as the
    latter is actually the documentation for the 'perldoc' program

* Wed Jan 14 2015 Paul Howarth <paul@city-fan.org> - 1:3.29-1
- Update to 3.29
  - NOTE: This will be the last release of Pod::Simple to support versions of
    Perl earlier than 5.6
  - Fixed test failure for unsupported encoding on Perl 5.6
  - Removed unnecessary dependency on constant (CPAN RT#85578)
  - Many documentation and comment typos fixed
  - Fixed issue when an encoding is declared via an '=encoding' directive
    *after* Pod::Simple has already detected an encoding
  - Added '>&STDERR' as an output to better emulate
    Pod::Parser::parse_from_file()
  - Tidied the description of the different Pod::Simple interfaces, with
    greater emphasis on the four different steps to subclassing
  - Added the 'top_anchor' attribue to Pod::Simple::HTML, to allow
    specification of a custom top anchor format
  - Fixed the text formatter to properly set the Text::Wrap overflow policy
  - Fixed mis-matched quotation marks when adding JavaScript elements to the
    XHTML output
  - Fixed issues on EBCDIC (PR#58)
  - Fixed bug where the value passed to Pod::Simple::XHTML's html_css()
    method would be output twice (CPAN RT#99303)
  - Documented the 'recurse' attribute of Pod::Simple::Search (CPAN RT#91886)
  - An error is no longer thrown when '=encoding' directives are found on
    subsequent lines; instead, we now log a an error message,
    "Cannot have multiple =encoding directives" (CPAN RT#91757)
  - The HTML and XHTML formatters now do a better job of preserving lines in
    'begin html' blocks (Perl RT#9385, CPAN RT#91851)

* Wed Sep 17 2014 Paul Howarth <paul@city-fan.org> - 1:3.28-310
- Classify buildreqs by usage
- Drop %%defattr, redundant since rpm 4.4

* Sun Jul 14 2013 Paul Howarth <paul@city-fan.org> - 1:3.28-3
- Perl 5.18 rebuild

* Sun May  5 2013 Paul Howarth <paul@city-fan.org> - 1:3.28-1
- Update to 3.28
  - Removed use of 'done_testing' in t/whine.t, which was added in v3.27
  - Fixed inproperly calculated number of skipped tests in t/xhtml01.t when
    HTML::Entities is not intalled
- Drop upstreamed patch for building with old Test::More versions

* Fri May  3 2013 Paul Howarth <paul@city-fan.org> - 1:3.27-1
- Update to 3.27
  - Added new warnings as defined by Pod::Checker, thanks to RJBS:
    - "=over" without "=back"
    - "L<>" starts or ends with whitespace
    - raw "|" or "/" in "L<text|link>" text
  - Added ->keep_encoding_directive, which is false by default, to prevent
    formatters from emitting a document's '=encoding' directive in most cases
    (that they emitted the encoding was a bug introduced in v3.26 -
    CPAN RT#84093); now, only the DumpAsText and DumpAsXML formats set it to
    true
- Add patch to support building with Test::More < 0.88

* Thu Feb 28 2013 Paul Howarth <paul@city-fan.org> - 1:3.26-1
- Update to 3.26
  - Fixed another test script to skip all tests when Encode is not installed
  - Added 'encoding()' and 'detected_encoding()' to return the current encoding
    and the encoding actually to decode the input file; the value from
    "=encoding" is also now kept in the output tree (CPAN RT#74390)

* Sun Feb 17 2013 Paul Howarth <paul@city-fan.org> - 1:3.25-1
- Update to 3.25
  - Improved the warning when "=item" types mismatch within one "=over"/"=back"
    block

* Fri Feb 15 2013 Paul Howarth <paul@city-fan.org> - 1:3.24-1
- Update to 3.24
  - Fixed corner case bug for unlikely scenario in which non-UTF-8 text could
    be parsed as UTF-8
  - XHTML IDs can no longer end with punctuation
  - Fixed test failure on Perl 5.6.2
  - Changed the default installation location from "perl" to "site" on 5.12 and
    higher, since as of that version of Perl, dual-life modules no longer need
    to be installed in "perl" to replace in-core versions
  - Fixed hash order dependency test failures on Perl 5.17
  - Inlined the code that tries to guess a Pod file's encoding, which reduces
    the time Pod::Simple takes to build the core Perl documentation by 15-20%%
  - Added a warning when "=item" types mismatch within one "=over"/"=back"
    block
  - Fixed regression introduced in 3.22 in which "C< >" tags were incorrectly
    treated as verbatim text in table of contents items emitted by
    Pod::Simple::XHTML
  - Loosened up the matching of "L< >" tags for man pages so that they allow
    names with dots, underscores, and any other characters other than "/",
    just so long as they end in '[(][-a-zA-Z0-9]+[)]' (CPAN RT#82975,
    CPAN RT#82972)
  - Fixed inverted mapping of "keyboard" to "kbd" in Pod::Simple::HTML
    (CPAN RT#79201)
  - Added two new Tagmap entries to Pod::Simple::HTML: "preformat" maps to
    "pre", and "teletype" maps to "tt" (CPAN RT#79201)
  - "X< >" tags are now ignored by the pull parser when it searches for
    titles, as is any trailing whitespace (CPAN RT#74389)
- Drop UTF-8 patch, no longer needed

* Mon Aug 20 2012 Paul Howarth <paul@city-fan.org> - 1:3.23-1
- Update to 3.23
  - Eliminated nested elements in table of contents (index) items output of
    Pod::Simple::XHTML, which was especially problematic for headers that
    included links, as the TOC then got nested anchor elements, which simply
    would not work (CPAN RT#77686)
  - Fixed semantically invalid nested XHTML generated by Pod::Simple::XHTML
    since v3.21
  - Improved support for nested "C< >" tags in Pod::Simple::XHTML
  - No longer tries to decode a string with the "utf8" flag set, as the
    double-decoding only triggered an error
  - Added documentation note that the API expects encoded text (octets)
  - Added "parse_characters()" option to specify that strings to parse are
    already decoded from octets into characters

* Mon Jun 11 2012 Paul Howarth <paul@city-fan.org> - 1:3.22-2
- Drop buildreqs for non-dual-lived modules: perl(File::Basename),
  perl(File::Find), perl(integer), perl(overload), perl(strict)

* Mon May 28 2012 Paul Howarth <paul@city-fan.org> - 1:3.22-1
- Update to 3.22
  - Fix bug where Pod::Simple would whine about non-ASCII bytes in code or
    comments - now only does so for Pod (in the absence of an "=encoding" tag)

* Wed May 23 2012 Paul Howarth <paul@city-fan.org> - 1:3.21-1
- Update to 3.21
  - NOTE: COMPATIBILITY CHANGE: the 'codes_in_verbatim' option in
    Pod::Simple::XHTML is no longer enabled by default, which brings it into
    agreement with the other formatting classes, and eliminates unexpected
    behavior in XHTML-formatted Pod; users who depended on this functionality
    can still get it by enabling 'codes_in_verbatim' in their code
  - Fixed some typos in the documentation (CPAN RT#75532)
  - Now emit a warning the first time a non-ASCII byte is encountered when no
    "=encoding" has been seen
  - When a non-ASCII byte is encounted before an "=encoding" line has been
    seen, a heuristic (as described in perlpodspec) is applied to select UTF-8
    encoding if the non-ASCII bytes form a valid UTF-8 byte sequence, or
    Latin-1 otherwise
  - Added 'handle_code' method to Pod::Simple::XHTML, which allows subclasses
    to override the handling of verbatim blocks, and makes for a more cohesive
    interface, to boot
  - Subsequent text segments are now joined together and passed as a single
    unit to text handling code, which makes it easier for custom handlers to
    process complete blocks of text in a single call to 'handle_text', rather
    than in dribs and drabs
  - Replaced naïve text wrapping code in Pod::Simple::DumpAsXML with
    Text::Wrap, which was already used for similar purposes elsewhere in
    Pod::Simple
- BR: perl(Data::Dumper)
- Don't need to remove empty directories from buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Fri Mar  2 2012 Paul Howarth <paul@city-fan.org> - 1:3.20-1
- Update to 3.20
  - Removed use of 'done_testing' in t/xhtml15.t, which was added in v3.19
  - Fixed quoting of links in a regular expression Pod::Simple::Text
  - Fix test failure on case-insensitive, non-case-preserving file systems (VMS
    I'm looking at *you*)
  - Pod::Simple::HTML no longer emits "href='#___top'" if a TOC (index) is not
    output
  - Fixed links in the TOC of XHTML output to use IDs derived from encoded
    text, rather than raw Pod, so that it will link to the ID actually
    generated for the section (CPAN RT#72544)
  - PullParser now throws an exception on an attempt to set a source more than
    once, which is necessary because data from the previous source will be
    cached, so the new source would be ignored anyway; create a new PullParser,
    instead (CPAN RT#74265)
- Drop patch for building with old Test::More versions, no longer needed
- Add buildreqs for Perl core modules that might be dual-lived

* Wed Aug 24 2011 Paul Howarth <paul@city-fan.org> - 1:3.19-1
- Update to 3.19
  - Fixed occasional test failure when tests are run in parallel
    (HARNESS_OPTIONS=j6:c)
  - Added "pod_handler" option, a callback that can be used to inspect the
    content on a "=pod" line
  - Added tests for proper line-ending parsing from the previous release
  - Added the "parse_empty_lists" option (disabled by default); when enabled,
    Pod::Simple will recognize empty lists (that is, a blocks with '=over' and
    '=back' but nothing in between)
  - Added the "whiteline_handler" attribute, much like "code_handler",
    "cut_handler", and "pod_handler", except it's triggered on lines that
    contain only whitespace characters
  - Added "raw" attribute to L<> treelet that contains the L<>'s raw contents
  - Pod directives autoclosed by Pod::Simple are now denoted as such by the new
    "fake_closer" attribute
  - Fixed incompatibility with Pod::Simple::HTMLBatch in Pod::Simple::XHTML
- Use a patch rather than scripted iconv to fix character encoding
- BR: perl(HTML::Entities)
- Add patch to support building with Test::More < 0.88 (CPAN RT#70456)

* Sun Jul 17 2011 Paul Howarth <paul@city-fan.org> - 1:3.18-2
- Rebuild for perl 5.14.1 in Rawhide

* Sun Jul 17 2011 Paul Howarth <paul@city-fan.org> - 1:3.18-1
- Update to 3.18
  - Pod::Simple now properly parses Pod files using Mac OS Classic line-endings
    (\r)
  - Fixed test failure in t/search50.t when the test finds a .pod but the
    module is in a .pm
- Fix dist tag for CentOS 6 and Scientific Linux

* Sun Jul 10 2011 Paul Howarth <paul@city-fan.org> - 1:3.17-1
- Update to 3.17
  - Documented tertiary methods
  - Added "backlink" option to Pod::Simple::XHTML
  - Typos fixed in Pod::Simple::HTMLBatch
  - Fixed quoting of value returned by a "strip_verbatim_indent()" code
    reference so that regex meta characters are properly escaped
  - Added "anchor_items" option to Pod::Simple::XHMTL; this allows text items
    (which are output as <dt> elements) to have IDs that can be referenced in
    the "#" part of a URL
  - Added "recurse" option to Pod::Simple::Search, enabled by default; disable
    it to turn off recursion into subdirectories
  - Added documentation to clarify the behavior of the "content_seen" method
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation
- Nobody else likes macros for commands

* Mon Mar 14 2011 Paul Howarth <paul@city-fan.org> - 1:3.16-1
- Update to 3.16
  - Fixed invalid HTML generated for nested lists by Pod::Simple::XHTML
  - Replaced the invalid "<nobr>" tag - created for "S<>" - with
    '<span style="white-space: nowrap;">'
  - Fixed some nerbles in our own Pod
  - Improved the "Minimal code" example in Pod::Simple::HTML (CPAN RT#65428)
  - Added the html_charset() and html_encode_chars() attributes to
    Pod::Simple::XHTML (CPAN RT#29587)
  - Added "Minimal code" example to the Pod::Simple::XHTML documentation
  - Fixed mis-spelling of the "=encoding" markup in the parser (CPAN RT#24820)

* Fri Nov 12 2010 Paul Howarth <paul@city-fan.org> - 1:3.15-1
- Bump epoch to match Fedora package

* Fri Nov 12 2010 Paul Howarth <paul@city-fan.org> - 3.15-1
- Update to 3.15
  - Removed "perlpod.pod" and "perlpodspec.pod", which now just live in the
    Perl core
  - Fixed stylesheet names output by HTMLBatch to match the names of the actual
    stylesheet files (broken in 3.09 - CPAN RT#56725)
  - Added missing closing slash to the CSS links in the XHTML output
  - Added parens around bar "qw(...)" in t/xhtml05.t
  - Improved the Pod::Simple::HTML docs
  - Pod::Simple::XHTML now properly encodes entities in URLs in the anchor tag
    (CPAN RT#60249)
  - Pod::Simple::HTML and XHTML now strip whitespace from the end of section
    names that appear as anchor names for headers (in HTML) and IDs (in XHTML);
    such whitespace appeared when "X<>" entities were stripped out but not the
    space between them (CPAN RT#56572)
  - Make test "t/search50.t" always pass on case-insensitive file systems
    rather than just skip VMS

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 3.14-3
- Rebuild for perl 5.12.1 in Rawhide

* Fri May  7 2010 Paul Howarth <paul@city-fan.org> - 3.14-2
- Fix dist tag to work with RHEL6 Beta

* Wed Apr 28 2010 Paul Howarth <paul@city-fan.org> - 3.14-1
- Update to 3.14
  - Removed explicit loading of UNIVERSAL
  - Reversed change applied in release 3.09 for CPAN RT#12239 (CPAN RT#55602)

* Mon Dec 21 2009 Paul Howarth <paul@city-fan.org> - 3.13-1
- Update to 3.13 (see ChangeLog for details)

* Thu Dec 10 2009 Paul Howarth <paul@city-fan.org> - 3.11-1
- Update to 3.11 (see ChangeLog for details)
- Dist tag for Rawhide no longer needs special-casing

* Fri Nov 13 2009 Paul Howarth <paul@city-fan.org> - 3.10-1
- Update to 3.10
  - fix test file line endings (CPAN RT#50922)
  - skip tests on VMS due to lack of filename case preservation (CPAN RT#51184)
  - fix nested definition list format in the XHTML output (CPAN RT#51187)
  - re-add files missing from last two releases
- New upstream maintainer -> new source URL
- Drop redundant manual dependency on perl(Pod::Escapes) >= 1.04

* Tue Oct 27 2009 Paul Howarth <paul@city-fan.org> - 3.09-1
- Update to 3.09
  - Many bugfixes including CPAN RT#{43903,40450,49615,37107,12239}
  - See ChangeLog for details
- Mark %%{perl_vendorlib}/Pod/Simple/Subclassing.pod as %%doc
- Own directory %%{perl_vendorlib}/Pod/

* Fri Jul 17 2009 Paul Howarth <paul@city-fan.org> - 3.08-1
- Update to 3.08
  * fix installdirs for Perl versions where Pod::Simple was core
  - (RT#36446, RT#39709)
  * fix encoding handling for code in paragraphs (RT#45829)
- Define RPM macros in global scope

* Thu Nov 13 2008 Paul Howarth <paul@city-fan.org> - 3.07-2
- Tweak dist tag macros to work on current Rawhide with three-part releasenum

* Thu Jun  7 2007 Paul Howarth <paul@city-fan.org> - 3.07-1
- Update to 3.07
- Clarify license as GPL version 1 or later, or Artistic (i.e. same as perl)
- Convert ChangeLog to UTF8
- Buildrequire ExtUtils::MakeMaker and Test::More

* Mon Mar  5 2007 Paul Howarth <paul@city-fan.org> - 3.05-1
- Update to 3.05
- Fix argument order for find with -depth
- Fix dist tag for Fedora 7 onwards

* Thu Jan 19 2006 Paul Howarth <paul@city-fan.org> - 3.04-1
- Update to 3.04

* Tue Nov 22 2005 Paul Howarth <paul@city-fan.org> - 3.03-1
- Update to 3.03
- Simplify distribution-detection (no rpmdb access)
- Use search.cpan.org URLs
- Remove redundant compiler optimization settings, not needed for noarch pkg
- Remove buildroot unconditionally in %%clean and %%install
- Don't use macros in paths for build-time commands, hardcode them instead
- Mark %%{perl_vendorlib}/Pod/Simple.pod as %%doc

* Thu Jun 23 2005 Paul Howarth <paul@city-fan.org> - 3.02-2
- Rewrite spec file in (mainly) Fedora Extras style
- Include full URL for source
- Fix URL
- Use MODULE_COMPAT dependency style and remove explicit perl dependency
- Remove MANIFEST from %%doc
- Exclude POD docs that are part of perl itself, and duplicate POD manpages too

* Wed Oct 27 2004 Paul Howarth <paul@city-fan.org> - 3.02-1
- Update to 3.02
- Tidy up spec file

* Mon May 10 2004 Paul Howarth <paul@city-fan.org> - 2.06-1
- Initial build
